@@ -11,5 +11,5 @@ pub use rand_pcg;
 pub use random::*;
 pub use rect::*;
 
-pub use glam;
+pub use glam::*;
 pub use utils::*;
